<?php
/**
 * ImageManager Provider - Ignite Gallery
 *
 * @author 		R2H - Michael Snoeren
 * @link 		https://r2h.nl/
 * @license     GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
 */

// Deny direct access
defined('_JEXEC') or die;

class plgImproviderIgniteGallery extends JPlugin {
	/**
	 * Autoload the languages
	 * @var 	Boolean
	 * @access 	Protected
	 */
	protected $autoloadLanguage = true;
	protected $images 			= array();

	/**
	 * Provide basic data about your plugin
	 * @access 	Public
	 * @return 	Array
	 */
	public function onProviderIdentify() {
		return array(
			'title' 			=> JText::_('PLG_IMPROVIDER_IGNITEGALLERY_TITLE'),
			'author' 			=> JText::_('PLG_IMPROVIDER_IGNITEGALLERY_AUTHOR'),
			'description' 		=> JText::_('PLG_IMPROVIDER_IGNITEGALLERY_DESCRIPTION'),
			'version' 			=> '',
			'createdOn' 		=> '10-05-2017',
			'license' 			=> 'GNU/GPLv3'
		);
	}

	/**
	 * Prepare the list of images
	 * @param 	Array 	$images 	The image array with relative paths from the server root (so images/banners/white.png)
	 * @access 	Public
	 * @return 	Void
	 */
	public function onProviderPrepare($images) {
		JLoader::register('plgIMProviderIgniteGalleryModelImage', JPATH_ROOT . '/plugins/improvider/ignitegallery/models/image.php');

		$model 					= new plgIMProviderIgniteGalleryModelImage;
		$this->images 			= $model->findUsage($images);
	}

	/**
	 * Get all used images
	 * @access 	Public
	 * @return 	Array
	 */
	public function onImagesGetUsed() {
		return array_filter($this->images);
	}
	/**
	 * Get all unused images
	 * @access 	Public
	 * @return 	Array
	 */
	public function onImagesGetUnused() {
		return array_filter($this->images, function($var) {
			return $var === false;
		});
	}

	/**
	 * Get the usage location of a given path
	 * @param 	String 	$path 	Relative image path
	 * @access 	Public
	 * @return 	Array|Null 		Null if not used, array(array('type' => 'TYPEOFLOCATION for example Custom HTML, Article or Store Product', title' => 'TITLEOFLOCATION for example Product Shoe', 'url' => 'null|URLTOITEM'))
	 */
	public function onImageGetLocations($path) {
		JLoader::register('plgIMProviderIgniteGalleryModelImage', JPATH_ROOT . '/plugins/improvider/ignitegallery/models/image.php');
		JLoader::register('plgIMProviderIgniteGalleryModelCategory', JPATH_ROOT . '/plugins/improvider/ignitegallery/models/category.php');

		$locationArray 			= array();

		// - Categories -------------------------
		$model 					= new plgIMProviderIgniteGalleryModelCategory;
		$images 				= $model->getLocations($path);

		if (count($images)) {
			foreach ($images as $img) {
				$locationArray[] = array(
					'type' 		=> JText::_('PLG_IMPROVIDER_IGNITEGALLERY_TYPE_CATEGORY'),
					'title' 	=> $img->name,
					'url' 		=> JRoute::_('index.php?option=com_igallery&view=icategory&id=' . $img->id)
				);
			}
		}
		// --------------------------------------

		// - Images -----------------------------
		$model 					= new plgIMProviderIgniteGalleryModelImage;
		$images 				= $model->getLocations($path);

		if (count($images)) {
			foreach ($images as $img) {
				$locationArray[] = array(
					'type' 		=> JText::_('PLG_IMPROVIDER_IGNITEGALLERY_TYPE_IMAGE'),
					'title' 	=> $img->filename,
					'url' 		=> JRoute::_('index.php?option=com_igallery&view=images&catid=' . $img->gallery_id . '&filter_search=' . $img->filename)
				);
			}
		}
		// --------------------------------------

		return $locationArray;
	}

	/**
	 * Replace the path of an image with a new one
	 * @param 	Array 	$images Key is the old path, value is the new path
	 * @access 	Public
	 * @return 	Boolean
	 */
	public function onImagesChangeLocation(array $images) {
		// Not supported for Ignite Gallery
		return true;
	}
}
